hotspot/src/cpu/sparc/vm/interpreter_sparc.cpp
changeset 35214 d86005e0b4c2
parent 34651 07b1cc0f6040
--- a/hotspot/src/cpu/sparc/vm/interpreter_sparc.cpp	Tue Dec 22 11:03:37 2015 +0100
+++ b/hotspot/src/cpu/sparc/vm/interpreter_sparc.cpp	Tue Dec 22 11:11:29 2015 -0500
@@ -26,9 +26,9 @@
 #include "asm/macroAssembler.hpp"
 #include "interpreter/bytecodeHistogram.hpp"
 #include "interpreter/interpreter.hpp"
-#include "interpreter/interpreterGenerator.hpp"
 #include "interpreter/interpreterRuntime.hpp"
 #include "interpreter/interp_masm.hpp"
+#include "interpreter/templateInterpreterGenerator.hpp"
 #include "interpreter/templateTable.hpp"
 #include "oops/arrayOop.hpp"
 #include "oops/methodData.hpp"
@@ -53,7 +53,7 @@
 
 // Generation of Interpreter
 //
 // The InterpreterGenerator generates the interpreter into Interpreter::_code.
 
 
 #define __ _masm->
@@ -194,7 +194,7 @@
 }
 #endif
 
-void InterpreterGenerator::generate_counter_overflow(Label& Lcontinue) {
+void TemplateInterpreterGenerator::generate_counter_overflow(Label& Lcontinue) {
 
   // Generate code to initiate compilation on the counter overflow.
 
@@ -219,7 +219,7 @@
 // Abstract method entry
 // Attempt to execute abstract method. Throw exception
 //
-address InterpreterGenerator::generate_abstract_entry(void) {
+address TemplateInterpreterGenerator::generate_abstract_entry(void) {
   address entry = __ pc();
   // abstract method entry
   // throw exception
@@ -53,7 +53,7 @@
 // Generation of Interpreter
 //
-// The InterpreterGenerator generates the interpreter into Interpreter::_code.
+// The TemplateInterpreterGenerator generates the interpreter into Interpreter::_code.
 
 